"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoaccessiprogGetPathParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetPathParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoaccessiprogGetPathParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetPathParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetPathParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetPathParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoaccessiprogGetPathParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetPathParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetPathParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetPathParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoaccessiprogGetPathParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetPathParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetPathParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetPathParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoaccessiprogGetPathParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetPathParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetPathParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetPathParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoaccessiprogGetPathParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetPathParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
