"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class PrognazareaGetPathParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazareaGetPathParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: PrognazareaGetPathParamInternalServerErrorData

    def __init__(
        self,
        data: PrognazareaGetPathParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazareaGetPathParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazareaGetPathParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: PrognazareaGetPathParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: PrognazareaGetPathParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazareaGetPathParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazareaGetPathParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: PrognazareaGetPathParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: PrognazareaGetPathParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazareaGetPathParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazareaGetPathParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: PrognazareaGetPathParamNotFoundErrorData

    def __init__(
        self,
        data: PrognazareaGetPathParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazareaGetPathParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazareaGetPathParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: PrognazareaGetPathParamBadRequestErrorData

    def __init__(
        self,
        data: PrognazareaGetPathParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
