"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoOdonimiGetPathParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetPathParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoOdonimiGetPathParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetPathParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetPathParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetPathParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoOdonimiGetPathParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetPathParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetPathParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetPathParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoOdonimiGetPathParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetPathParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetPathParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetPathParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoOdonimiGetPathParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetPathParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetPathParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetPathParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoOdonimiGetPathParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetPathParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
