"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PrognazareaPostRequestTypedDict(TypedDict):
    r"""search input data"""

    req: NotRequired[str]
    prognaz: NotRequired[str]


class PrognazareaPostRequest(BaseModel):
    r"""search input data"""

    req: Optional[str] = None

    prognaz: Optional[str] = None


class PrognazareaPostDataTypedDict(TypedDict):
    prognaz: NotRequired[str]
    dug: NotRequired[str]
    denomuff: NotRequired[str]
    denomloc: NotRequired[str]
    denomlingua1: NotRequired[str]
    denomlingua2: NotRequired[str]


class PrognazareaPostData(BaseModel):
    prognaz: Optional[str] = None

    dug: Optional[str] = None

    denomuff: Optional[str] = None

    denomloc: Optional[str] = None

    denomlingua1: Optional[str] = None

    denomlingua2: Optional[str] = None


class PrognazareaPostResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[List[PrognazareaPostDataTypedDict]]


class PrognazareaPostResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[List[PrognazareaPostData]] = None
