"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class PrognazaccGetPathParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazaccGetPathParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: PrognazaccGetPathParamInternalServerErrorData

    def __init__(
        self,
        data: PrognazaccGetPathParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazaccGetPathParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazaccGetPathParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: PrognazaccGetPathParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: PrognazaccGetPathParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazaccGetPathParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazaccGetPathParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: PrognazaccGetPathParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: PrognazaccGetPathParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazaccGetPathParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazaccGetPathParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: PrognazaccGetPathParamNotFoundErrorData

    def __init__(
        self,
        data: PrognazaccGetPathParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class PrognazaccGetPathParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class PrognazaccGetPathParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: PrognazaccGetPathParamBadRequestErrorData

    def __init__(
        self,
        data: PrognazaccGetPathParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
