"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

import importlib.metadata

__title__: str = "anncsu"
__openapi_doc_version__: str = "1.0.0"
__gen_version__: str = "2.667.0"
__user_agent__: str = "speakeasy-sdk/python 0.0.1 2.667.0 1.0.0 anncsu"

try:
    if __package__ is not None:
        __version__ = importlib.metadata.version(__name__)
except importlib.metadata.PackageNotFoundError:
    __version__ = "0.0.0"  # Fallback for development mode
