"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoodonimiprogGetPathParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetPathParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoodonimiprogGetPathParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetPathParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetPathParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetPathParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoodonimiprogGetPathParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetPathParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetPathParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetPathParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoodonimiprogGetPathParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetPathParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetPathParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetPathParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoodonimiprogGetPathParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetPathParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetPathParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetPathParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoodonimiprogGetPathParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetPathParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
