"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from anncsu.common.utils import FieldMetadata, PathParamMetadata
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class PrognazareaGetPathParamRequestTypedDict(TypedDict):
    prognaz: str
    r"""Progressivo nazionale dell'odonimo"""


class PrognazareaGetPathParamRequest(BaseModel):
    prognaz: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Progressivo nazionale dell'odonimo"""


class PrognazareaGetPathParamDataTypedDict(TypedDict):
    prognaz: NotRequired[str]
    dug: NotRequired[str]
    denomuff: NotRequired[str]
    denomloc: NotRequired[str]
    denomlingua1: NotRequired[str]
    denomlingua2: NotRequired[str]


class PrognazareaGetPathParamData(BaseModel):
    prognaz: Optional[str] = None

    dug: Optional[str] = None

    denomuff: Optional[str] = None

    denomloc: Optional[str] = None

    denomlingua1: Optional[str] = None

    denomlingua2: Optional[str] = None


class PrognazareaGetPathParamResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[List[PrognazareaGetPathParamDataTypedDict]]


class PrognazareaGetPathParamResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[List[PrognazareaGetPathParamData]] = None
