"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoOdonimiGetQueryParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetQueryParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoOdonimiGetQueryParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetQueryParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetQueryParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetQueryParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoOdonimiGetQueryParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetQueryParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetQueryParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetQueryParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoOdonimiGetQueryParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetQueryParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetQueryParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetQueryParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoOdonimiGetQueryParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetQueryParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoOdonimiGetQueryParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoOdonimiGetQueryParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoOdonimiGetQueryParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoOdonimiGetQueryParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
