"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from anncsu.common.utils import FieldMetadata, PathParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EsisteOdonimoGetPathParamRequestTypedDict(TypedDict):
    codcom: str
    r"""Codice Belfiore del comune dell'odonimo"""
    denom: str
    r"""Denominazione esatta dell'odonimo - base64 encoded"""


class EsisteOdonimoGetPathParamRequest(BaseModel):
    codcom: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Codice Belfiore del comune dell'odonimo"""

    denom: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Denominazione esatta dell'odonimo - base64 encoded"""


class EsisteOdonimoGetPathParamResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[bool]


class EsisteOdonimoGetPathParamResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[bool] = None
