"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ShowStatusResponseTypedDict(TypedDict):
    r"""Il server ha ritornato lo status."""

    status: NotRequired[str]


class ShowStatusResponse(BaseModel):
    r"""Il server ha ritornato lo status."""

    status: Optional[str] = None
