"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoodonimiprogGetQueryParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetQueryParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoodonimiprogGetQueryParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetQueryParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetQueryParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetQueryParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetQueryParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetQueryParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoodonimiprogGetQueryParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetQueryParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoodonimiprogGetQueryParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoodonimiprogGetQueryParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoodonimiprogGetQueryParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoodonimiprogGetQueryParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
