"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from anncsu.common.utils import FieldMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class EsisteAccessoGetQueryParamRequestTypedDict(TypedDict):
    codcom: str
    r"""Codice Belfiore del comune dell'odonimo"""
    denom: str
    r"""Denominazione esatta dell'odonimo - base64 encoded"""
    accesso: str
    r"""valore civico(+eventuale esponente e/o specificit�) oppure metrico"""


class EsisteAccessoGetQueryParamRequest(BaseModel):
    codcom: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""Codice Belfiore del comune dell'odonimo"""

    denom: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""Denominazione esatta dell'odonimo - base64 encoded"""

    accesso: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""valore civico(+eventuale esponente e/o specificit�) oppure metrico"""


class EsisteAccessoGetQueryParamResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[bool]


class EsisteAccessoGetQueryParamResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[bool] = None
