"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .elencoaccessigetpathparamop import (
        ElencoAccessiGetPathParamData,
        ElencoAccessiGetPathParamDataTypedDict,
        ElencoAccessiGetPathParamRequest,
        ElencoAccessiGetPathParamRequestTypedDict,
        ElencoAccessiGetPathParamResponse,
        ElencoAccessiGetPathParamResponseTypedDict,
    )
    from .elencoaccessigetqueryparamop import (
        ElencoAccessiGetQueryParamData,
        ElencoAccessiGetQueryParamDataTypedDict,
        ElencoAccessiGetQueryParamRequest,
        ElencoAccessiGetQueryParamRequestTypedDict,
        ElencoAccessiGetQueryParamResponse,
        ElencoAccessiGetQueryParamResponseTypedDict,
    )
    from .elencoaccessipostop import (
        ElencoAccessiPostData,
        ElencoAccessiPostDataTypedDict,
        ElencoAccessiPostRequest,
        ElencoAccessiPostRequestTypedDict,
        ElencoAccessiPostResponse,
        ElencoAccessiPostResponseTypedDict,
    )
    from .elencoaccessiproggetpathparamop import (
        ElencoaccessiprogGetPathParamData,
        ElencoaccessiprogGetPathParamDataTypedDict,
        ElencoaccessiprogGetPathParamRequest,
        ElencoaccessiprogGetPathParamRequestTypedDict,
        ElencoaccessiprogGetPathParamResponse,
        ElencoaccessiprogGetPathParamResponseTypedDict,
    )
    from .elencoaccessiproggetqueryparamop import (
        ElencoaccessiprogGetQueryParamData,
        ElencoaccessiprogGetQueryParamDataTypedDict,
        ElencoaccessiprogGetQueryParamRequest,
        ElencoaccessiprogGetQueryParamRequestTypedDict,
        ElencoaccessiprogGetQueryParamResponse,
        ElencoaccessiprogGetQueryParamResponseTypedDict,
    )
    from .elencoaccessiprogpostop import (
        ElencoaccessiprogPostData,
        ElencoaccessiprogPostDataTypedDict,
        ElencoaccessiprogPostRequest,
        ElencoaccessiprogPostRequestTypedDict,
        ElencoaccessiprogPostResponse,
        ElencoaccessiprogPostResponseTypedDict,
    )
    from .elencoodonimigetpathparamop import (
        ElencoOdonimiGetPathParamData,
        ElencoOdonimiGetPathParamDataTypedDict,
        ElencoOdonimiGetPathParamRequest,
        ElencoOdonimiGetPathParamRequestTypedDict,
        ElencoOdonimiGetPathParamResponse,
        ElencoOdonimiGetPathParamResponseTypedDict,
    )
    from .elencoodonimigetqueryparamop import (
        ElencoOdonimiGetQueryParamData,
        ElencoOdonimiGetQueryParamDataTypedDict,
        ElencoOdonimiGetQueryParamRequest,
        ElencoOdonimiGetQueryParamRequestTypedDict,
        ElencoOdonimiGetQueryParamResponse,
        ElencoOdonimiGetQueryParamResponseTypedDict,
    )
    from .elencoodonimipostop import (
        ElencoOdonimiPostData,
        ElencoOdonimiPostDataTypedDict,
        ElencoOdonimiPostRequest,
        ElencoOdonimiPostRequestTypedDict,
        ElencoOdonimiPostResponse,
        ElencoOdonimiPostResponseTypedDict,
    )
    from .elencoodonimiproggetpathparamop import (
        ElencoodonimiprogGetPathParamData,
        ElencoodonimiprogGetPathParamDataTypedDict,
        ElencoodonimiprogGetPathParamRequest,
        ElencoodonimiprogGetPathParamRequestTypedDict,
        ElencoodonimiprogGetPathParamResponse,
        ElencoodonimiprogGetPathParamResponseTypedDict,
    )
    from .elencoodonimiproggetqueryparamop import (
        ElencoodonimiprogGetQueryParamData,
        ElencoodonimiprogGetQueryParamDataTypedDict,
        ElencoodonimiprogGetQueryParamRequest,
        ElencoodonimiprogGetQueryParamRequestTypedDict,
        ElencoodonimiprogGetQueryParamResponse,
        ElencoodonimiprogGetQueryParamResponseTypedDict,
    )
    from .elencoodonimiprogpostop import (
        ElencoodonimiprogPostData,
        ElencoodonimiprogPostDataTypedDict,
        ElencoodonimiprogPostRequest,
        ElencoodonimiprogPostRequestTypedDict,
        ElencoodonimiprogPostResponse,
        ElencoodonimiprogPostResponseTypedDict,
    )
    from .esisteaccessogetpathparamop import (
        EsisteAccessoGetPathParamRequest,
        EsisteAccessoGetPathParamRequestTypedDict,
        EsisteAccessoGetPathParamResponse,
        EsisteAccessoGetPathParamResponseTypedDict,
    )
    from .esisteaccessogetqueryparamop import (
        EsisteAccessoGetQueryParamRequest,
        EsisteAccessoGetQueryParamRequestTypedDict,
        EsisteAccessoGetQueryParamResponse,
        EsisteAccessoGetQueryParamResponseTypedDict,
    )
    from .esisteaccessopostop import (
        EsisteAccessoPostRequest,
        EsisteAccessoPostRequestTypedDict,
        EsisteAccessoPostResponse,
        EsisteAccessoPostResponseTypedDict,
    )
    from .esisteodonimogetpathparamop import (
        EsisteOdonimoGetPathParamRequest,
        EsisteOdonimoGetPathParamRequestTypedDict,
        EsisteOdonimoGetPathParamResponse,
        EsisteOdonimoGetPathParamResponseTypedDict,
    )
    from .esisteodonimogetqueryparamop import (
        EsisteOdonimoGetQueryParamRequest,
        EsisteOdonimoGetQueryParamRequestTypedDict,
        EsisteOdonimoGetQueryParamResponse,
        EsisteOdonimoGetQueryParamResponseTypedDict,
    )
    from .esisteodonimopostop import (
        EsisteOdonimoPostRequest,
        EsisteOdonimoPostRequestTypedDict,
        EsisteOdonimoPostResponse,
        EsisteOdonimoPostResponseTypedDict,
    )
    from .prognazaccgetpathparamop import (
        PrognazaccGetPathParamData,
        PrognazaccGetPathParamDataTypedDict,
        PrognazaccGetPathParamRequest,
        PrognazaccGetPathParamRequestTypedDict,
        PrognazaccGetPathParamResponse,
        PrognazaccGetPathParamResponseTypedDict,
    )
    from .prognazaccgetqueryparamop import (
        PrognazaccGetQueryParamData,
        PrognazaccGetQueryParamDataTypedDict,
        PrognazaccGetQueryParamRequest,
        PrognazaccGetQueryParamRequestTypedDict,
        PrognazaccGetQueryParamResponse,
        PrognazaccGetQueryParamResponseTypedDict,
    )
    from .prognazaccpostop import (
        PrognazaccPostData,
        PrognazaccPostDataTypedDict,
        PrognazaccPostRequest,
        PrognazaccPostRequestTypedDict,
        PrognazaccPostResponse,
        PrognazaccPostResponseTypedDict,
    )
    from .prognazareagetpathparamop import (
        PrognazareaGetPathParamData,
        PrognazareaGetPathParamDataTypedDict,
        PrognazareaGetPathParamRequest,
        PrognazareaGetPathParamRequestTypedDict,
        PrognazareaGetPathParamResponse,
        PrognazareaGetPathParamResponseTypedDict,
    )
    from .prognazareagetqueryparamop import (
        PrognazareaGetQueryParamData,
        PrognazareaGetQueryParamDataTypedDict,
        PrognazareaGetQueryParamRequest,
        PrognazareaGetQueryParamRequestTypedDict,
        PrognazareaGetQueryParamResponse,
        PrognazareaGetQueryParamResponseTypedDict,
    )
    from .prognazareapostop import (
        PrognazareaPostData,
        PrognazareaPostDataTypedDict,
        PrognazareaPostRequest,
        PrognazareaPostRequestTypedDict,
        PrognazareaPostResponse,
        PrognazareaPostResponseTypedDict,
    )
    from .show_statusop import ShowStatusResponse, ShowStatusResponseTypedDict

__all__ = [
    "ElencoAccessiGetPathParamData",
    "ElencoAccessiGetPathParamDataTypedDict",
    "ElencoAccessiGetPathParamRequest",
    "ElencoAccessiGetPathParamRequestTypedDict",
    "ElencoAccessiGetPathParamResponse",
    "ElencoAccessiGetPathParamResponseTypedDict",
    "ElencoAccessiGetQueryParamData",
    "ElencoAccessiGetQueryParamDataTypedDict",
    "ElencoAccessiGetQueryParamRequest",
    "ElencoAccessiGetQueryParamRequestTypedDict",
    "ElencoAccessiGetQueryParamResponse",
    "ElencoAccessiGetQueryParamResponseTypedDict",
    "ElencoAccessiPostData",
    "ElencoAccessiPostDataTypedDict",
    "ElencoAccessiPostRequest",
    "ElencoAccessiPostRequestTypedDict",
    "ElencoAccessiPostResponse",
    "ElencoAccessiPostResponseTypedDict",
    "ElencoOdonimiGetPathParamData",
    "ElencoOdonimiGetPathParamDataTypedDict",
    "ElencoOdonimiGetPathParamRequest",
    "ElencoOdonimiGetPathParamRequestTypedDict",
    "ElencoOdonimiGetPathParamResponse",
    "ElencoOdonimiGetPathParamResponseTypedDict",
    "ElencoOdonimiGetQueryParamData",
    "ElencoOdonimiGetQueryParamDataTypedDict",
    "ElencoOdonimiGetQueryParamRequest",
    "ElencoOdonimiGetQueryParamRequestTypedDict",
    "ElencoOdonimiGetQueryParamResponse",
    "ElencoOdonimiGetQueryParamResponseTypedDict",
    "ElencoOdonimiPostData",
    "ElencoOdonimiPostDataTypedDict",
    "ElencoOdonimiPostRequest",
    "ElencoOdonimiPostRequestTypedDict",
    "ElencoOdonimiPostResponse",
    "ElencoOdonimiPostResponseTypedDict",
    "ElencoaccessiprogGetPathParamData",
    "ElencoaccessiprogGetPathParamDataTypedDict",
    "ElencoaccessiprogGetPathParamRequest",
    "ElencoaccessiprogGetPathParamRequestTypedDict",
    "ElencoaccessiprogGetPathParamResponse",
    "ElencoaccessiprogGetPathParamResponseTypedDict",
    "ElencoaccessiprogGetQueryParamData",
    "ElencoaccessiprogGetQueryParamDataTypedDict",
    "ElencoaccessiprogGetQueryParamRequest",
    "ElencoaccessiprogGetQueryParamRequestTypedDict",
    "ElencoaccessiprogGetQueryParamResponse",
    "ElencoaccessiprogGetQueryParamResponseTypedDict",
    "ElencoaccessiprogPostData",
    "ElencoaccessiprogPostDataTypedDict",
    "ElencoaccessiprogPostRequest",
    "ElencoaccessiprogPostRequestTypedDict",
    "ElencoaccessiprogPostResponse",
    "ElencoaccessiprogPostResponseTypedDict",
    "ElencoodonimiprogGetPathParamData",
    "ElencoodonimiprogGetPathParamDataTypedDict",
    "ElencoodonimiprogGetPathParamRequest",
    "ElencoodonimiprogGetPathParamRequestTypedDict",
    "ElencoodonimiprogGetPathParamResponse",
    "ElencoodonimiprogGetPathParamResponseTypedDict",
    "ElencoodonimiprogGetQueryParamData",
    "ElencoodonimiprogGetQueryParamDataTypedDict",
    "ElencoodonimiprogGetQueryParamRequest",
    "ElencoodonimiprogGetQueryParamRequestTypedDict",
    "ElencoodonimiprogGetQueryParamResponse",
    "ElencoodonimiprogGetQueryParamResponseTypedDict",
    "ElencoodonimiprogPostData",
    "ElencoodonimiprogPostDataTypedDict",
    "ElencoodonimiprogPostRequest",
    "ElencoodonimiprogPostRequestTypedDict",
    "ElencoodonimiprogPostResponse",
    "ElencoodonimiprogPostResponseTypedDict",
    "EsisteAccessoGetPathParamRequest",
    "EsisteAccessoGetPathParamRequestTypedDict",
    "EsisteAccessoGetPathParamResponse",
    "EsisteAccessoGetPathParamResponseTypedDict",
    "EsisteAccessoGetQueryParamRequest",
    "EsisteAccessoGetQueryParamRequestTypedDict",
    "EsisteAccessoGetQueryParamResponse",
    "EsisteAccessoGetQueryParamResponseTypedDict",
    "EsisteAccessoPostRequest",
    "EsisteAccessoPostRequestTypedDict",
    "EsisteAccessoPostResponse",
    "EsisteAccessoPostResponseTypedDict",
    "EsisteOdonimoGetPathParamRequest",
    "EsisteOdonimoGetPathParamRequestTypedDict",
    "EsisteOdonimoGetPathParamResponse",
    "EsisteOdonimoGetPathParamResponseTypedDict",
    "EsisteOdonimoGetQueryParamRequest",
    "EsisteOdonimoGetQueryParamRequestTypedDict",
    "EsisteOdonimoGetQueryParamResponse",
    "EsisteOdonimoGetQueryParamResponseTypedDict",
    "EsisteOdonimoPostRequest",
    "EsisteOdonimoPostRequestTypedDict",
    "EsisteOdonimoPostResponse",
    "EsisteOdonimoPostResponseTypedDict",
    "PrognazaccGetPathParamData",
    "PrognazaccGetPathParamDataTypedDict",
    "PrognazaccGetPathParamRequest",
    "PrognazaccGetPathParamRequestTypedDict",
    "PrognazaccGetPathParamResponse",
    "PrognazaccGetPathParamResponseTypedDict",
    "PrognazaccGetQueryParamData",
    "PrognazaccGetQueryParamDataTypedDict",
    "PrognazaccGetQueryParamRequest",
    "PrognazaccGetQueryParamRequestTypedDict",
    "PrognazaccGetQueryParamResponse",
    "PrognazaccGetQueryParamResponseTypedDict",
    "PrognazaccPostData",
    "PrognazaccPostDataTypedDict",
    "PrognazaccPostRequest",
    "PrognazaccPostRequestTypedDict",
    "PrognazaccPostResponse",
    "PrognazaccPostResponseTypedDict",
    "PrognazareaGetPathParamData",
    "PrognazareaGetPathParamDataTypedDict",
    "PrognazareaGetPathParamRequest",
    "PrognazareaGetPathParamRequestTypedDict",
    "PrognazareaGetPathParamResponse",
    "PrognazareaGetPathParamResponseTypedDict",
    "PrognazareaGetQueryParamData",
    "PrognazareaGetQueryParamDataTypedDict",
    "PrognazareaGetQueryParamRequest",
    "PrognazareaGetQueryParamRequestTypedDict",
    "PrognazareaGetQueryParamResponse",
    "PrognazareaGetQueryParamResponseTypedDict",
    "PrognazareaPostData",
    "PrognazareaPostDataTypedDict",
    "PrognazareaPostRequest",
    "PrognazareaPostRequestTypedDict",
    "PrognazareaPostResponse",
    "PrognazareaPostResponseTypedDict",
    "ShowStatusResponse",
    "ShowStatusResponseTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "ElencoAccessiGetPathParamData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamDataTypedDict": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamRequest": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamRequestTypedDict": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamResponse": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamResponseTypedDict": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetQueryParamData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamDataTypedDict": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamRequest": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamRequestTypedDict": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamResponse": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamResponseTypedDict": ".elencoaccessigetqueryparamop",
    "ElencoAccessiPostData": ".elencoaccessipostop",
    "ElencoAccessiPostDataTypedDict": ".elencoaccessipostop",
    "ElencoAccessiPostRequest": ".elencoaccessipostop",
    "ElencoAccessiPostRequestTypedDict": ".elencoaccessipostop",
    "ElencoAccessiPostResponse": ".elencoaccessipostop",
    "ElencoAccessiPostResponseTypedDict": ".elencoaccessipostop",
    "ElencoaccessiprogGetPathParamData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamDataTypedDict": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamRequest": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamRequestTypedDict": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamResponse": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamResponseTypedDict": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetQueryParamData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamDataTypedDict": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamRequest": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamRequestTypedDict": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamResponse": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamResponseTypedDict": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogPostData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostDataTypedDict": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostRequest": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostRequestTypedDict": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostResponse": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostResponseTypedDict": ".elencoaccessiprogpostop",
    "ElencoOdonimiGetPathParamData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamDataTypedDict": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamRequest": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamRequestTypedDict": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamResponse": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamResponseTypedDict": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetQueryParamData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamDataTypedDict": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamRequest": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamRequestTypedDict": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamResponse": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamResponseTypedDict": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiPostData": ".elencoodonimipostop",
    "ElencoOdonimiPostDataTypedDict": ".elencoodonimipostop",
    "ElencoOdonimiPostRequest": ".elencoodonimipostop",
    "ElencoOdonimiPostRequestTypedDict": ".elencoodonimipostop",
    "ElencoOdonimiPostResponse": ".elencoodonimipostop",
    "ElencoOdonimiPostResponseTypedDict": ".elencoodonimipostop",
    "ElencoodonimiprogGetPathParamData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamDataTypedDict": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamRequest": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamRequestTypedDict": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamResponse": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamResponseTypedDict": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetQueryParamData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamDataTypedDict": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamRequest": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamRequestTypedDict": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamResponse": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamResponseTypedDict": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogPostData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostDataTypedDict": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostRequest": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostRequestTypedDict": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostResponse": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostResponseTypedDict": ".elencoodonimiprogpostop",
    "EsisteAccessoGetPathParamRequest": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamRequestTypedDict": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamResponse": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamResponseTypedDict": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetQueryParamRequest": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamRequestTypedDict": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamResponse": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamResponseTypedDict": ".esisteaccessogetqueryparamop",
    "EsisteAccessoPostRequest": ".esisteaccessopostop",
    "EsisteAccessoPostRequestTypedDict": ".esisteaccessopostop",
    "EsisteAccessoPostResponse": ".esisteaccessopostop",
    "EsisteAccessoPostResponseTypedDict": ".esisteaccessopostop",
    "EsisteOdonimoGetPathParamRequest": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamRequestTypedDict": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamResponse": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamResponseTypedDict": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetQueryParamRequest": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamRequestTypedDict": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamResponse": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamResponseTypedDict": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoPostRequest": ".esisteodonimopostop",
    "EsisteOdonimoPostRequestTypedDict": ".esisteodonimopostop",
    "EsisteOdonimoPostResponse": ".esisteodonimopostop",
    "EsisteOdonimoPostResponseTypedDict": ".esisteodonimopostop",
    "PrognazaccGetPathParamData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamDataTypedDict": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamRequest": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamRequestTypedDict": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamResponse": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamResponseTypedDict": ".prognazaccgetpathparamop",
    "PrognazaccGetQueryParamData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamDataTypedDict": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamRequest": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamRequestTypedDict": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamResponse": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamResponseTypedDict": ".prognazaccgetqueryparamop",
    "PrognazaccPostData": ".prognazaccpostop",
    "PrognazaccPostDataTypedDict": ".prognazaccpostop",
    "PrognazaccPostRequest": ".prognazaccpostop",
    "PrognazaccPostRequestTypedDict": ".prognazaccpostop",
    "PrognazaccPostResponse": ".prognazaccpostop",
    "PrognazaccPostResponseTypedDict": ".prognazaccpostop",
    "PrognazareaGetPathParamData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamDataTypedDict": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamRequest": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamRequestTypedDict": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamResponse": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamResponseTypedDict": ".prognazareagetpathparamop",
    "PrognazareaGetQueryParamData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamDataTypedDict": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamRequest": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamRequestTypedDict": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamResponse": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamResponseTypedDict": ".prognazareagetqueryparamop",
    "PrognazareaPostData": ".prognazareapostop",
    "PrognazareaPostDataTypedDict": ".prognazareapostop",
    "PrognazareaPostRequest": ".prognazareapostop",
    "PrognazareaPostRequestTypedDict": ".prognazareapostop",
    "PrognazareaPostResponse": ".prognazareapostop",
    "PrognazareaPostResponseTypedDict": ".prognazareapostop",
    "ShowStatusResponse": ".show_statusop",
    "ShowStatusResponseTypedDict": ".show_statusop",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
