"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ElencoOdonimiPostRequestTypedDict(TypedDict):
    r"""search input data"""

    req: NotRequired[str]
    codcom: NotRequired[str]
    denomparz: NotRequired[str]


class ElencoOdonimiPostRequest(BaseModel):
    r"""search input data"""

    req: Optional[str] = None

    codcom: Optional[str] = None

    denomparz: Optional[str] = None


class ElencoOdonimiPostDataTypedDict(TypedDict):
    dug: NotRequired[str]
    denomuff: NotRequired[str]
    denomloc: NotRequired[str]
    denomlingua1: NotRequired[str]
    denomlingua2: NotRequired[str]


class ElencoOdonimiPostData(BaseModel):
    dug: Optional[str] = None

    denomuff: Optional[str] = None

    denomloc: Optional[str] = None

    denomlingua1: Optional[str] = None

    denomlingua2: Optional[str] = None


class ElencoOdonimiPostResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[List[ElencoOdonimiPostDataTypedDict]]


class ElencoOdonimiPostResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[List[ElencoOdonimiPostData]] = None
