"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ElencoAccessiPostRequestTypedDict(TypedDict):
    r"""search input data"""

    req: NotRequired[str]
    codcom: NotRequired[str]
    denom: NotRequired[str]
    accparz: NotRequired[str]


class ElencoAccessiPostRequest(BaseModel):
    r"""search input data"""

    req: Optional[str] = None

    codcom: Optional[str] = None

    denom: Optional[str] = None

    accparz: Optional[str] = None


class ElencoAccessiPostDataTypedDict(TypedDict):
    civico: NotRequired[str]
    esp: NotRequired[str]
    specif: NotRequired[str]
    metrico: NotRequired[str]


class ElencoAccessiPostData(BaseModel):
    civico: Optional[str] = None

    esp: Optional[str] = None

    specif: Optional[str] = None

    metrico: Optional[str] = None


class ElencoAccessiPostResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[List[ElencoAccessiPostDataTypedDict]]


class ElencoAccessiPostResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[List[ElencoAccessiPostData]] = None
