"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .anncsuerror import AnncsuError
    from .apierror import APIError
    from .elencoaccessigetpathparamop import (
        ElencoAccessiGetPathParamBadRequestError,
        ElencoAccessiGetPathParamBadRequestErrorData,
        ElencoAccessiGetPathParamInternalServerError,
        ElencoAccessiGetPathParamInternalServerErrorData,
        ElencoAccessiGetPathParamMethodNotAllowedError,
        ElencoAccessiGetPathParamMethodNotAllowedErrorData,
        ElencoAccessiGetPathParamNotFoundError,
        ElencoAccessiGetPathParamNotFoundErrorData,
        ElencoAccessiGetPathParamUnprocessableEntityError,
        ElencoAccessiGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoaccessigetqueryparamop import (
        ElencoAccessiGetQueryParamBadRequestError,
        ElencoAccessiGetQueryParamBadRequestErrorData,
        ElencoAccessiGetQueryParamInternalServerError,
        ElencoAccessiGetQueryParamInternalServerErrorData,
        ElencoAccessiGetQueryParamMethodNotAllowedError,
        ElencoAccessiGetQueryParamMethodNotAllowedErrorData,
        ElencoAccessiGetQueryParamNotFoundError,
        ElencoAccessiGetQueryParamNotFoundErrorData,
        ElencoAccessiGetQueryParamUnprocessableEntityError,
        ElencoAccessiGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoaccessipostop import (
        ElencoAccessiPostBadRequestError,
        ElencoAccessiPostBadRequestErrorData,
        ElencoAccessiPostInternalServerError,
        ElencoAccessiPostInternalServerErrorData,
        ElencoAccessiPostMethodNotAllowedError,
        ElencoAccessiPostMethodNotAllowedErrorData,
        ElencoAccessiPostNotFoundError,
        ElencoAccessiPostNotFoundErrorData,
        ElencoAccessiPostUnprocessableEntityError,
        ElencoAccessiPostUnprocessableEntityErrorData,
    )
    from .elencoaccessiproggetpathparamop import (
        ElencoaccessiprogGetPathParamBadRequestError,
        ElencoaccessiprogGetPathParamBadRequestErrorData,
        ElencoaccessiprogGetPathParamInternalServerError,
        ElencoaccessiprogGetPathParamInternalServerErrorData,
        ElencoaccessiprogGetPathParamMethodNotAllowedError,
        ElencoaccessiprogGetPathParamMethodNotAllowedErrorData,
        ElencoaccessiprogGetPathParamNotFoundError,
        ElencoaccessiprogGetPathParamNotFoundErrorData,
        ElencoaccessiprogGetPathParamUnprocessableEntityError,
        ElencoaccessiprogGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoaccessiproggetqueryparamop import (
        ElencoaccessiprogGetQueryParamBadRequestError,
        ElencoaccessiprogGetQueryParamBadRequestErrorData,
        ElencoaccessiprogGetQueryParamInternalServerError,
        ElencoaccessiprogGetQueryParamInternalServerErrorData,
        ElencoaccessiprogGetQueryParamMethodNotAllowedError,
        ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData,
        ElencoaccessiprogGetQueryParamNotFoundError,
        ElencoaccessiprogGetQueryParamNotFoundErrorData,
        ElencoaccessiprogGetQueryParamUnprocessableEntityError,
        ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoaccessiprogpostop import (
        ElencoaccessiprogPostBadRequestError,
        ElencoaccessiprogPostBadRequestErrorData,
        ElencoaccessiprogPostInternalServerError,
        ElencoaccessiprogPostInternalServerErrorData,
        ElencoaccessiprogPostMethodNotAllowedError,
        ElencoaccessiprogPostMethodNotAllowedErrorData,
        ElencoaccessiprogPostNotFoundError,
        ElencoaccessiprogPostNotFoundErrorData,
        ElencoaccessiprogPostUnprocessableEntityError,
        ElencoaccessiprogPostUnprocessableEntityErrorData,
    )
    from .elencoodonimigetpathparamop import (
        ElencoOdonimiGetPathParamBadRequestError,
        ElencoOdonimiGetPathParamBadRequestErrorData,
        ElencoOdonimiGetPathParamInternalServerError,
        ElencoOdonimiGetPathParamInternalServerErrorData,
        ElencoOdonimiGetPathParamMethodNotAllowedError,
        ElencoOdonimiGetPathParamMethodNotAllowedErrorData,
        ElencoOdonimiGetPathParamNotFoundError,
        ElencoOdonimiGetPathParamNotFoundErrorData,
        ElencoOdonimiGetPathParamUnprocessableEntityError,
        ElencoOdonimiGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoodonimigetqueryparamop import (
        ElencoOdonimiGetQueryParamBadRequestError,
        ElencoOdonimiGetQueryParamBadRequestErrorData,
        ElencoOdonimiGetQueryParamInternalServerError,
        ElencoOdonimiGetQueryParamInternalServerErrorData,
        ElencoOdonimiGetQueryParamMethodNotAllowedError,
        ElencoOdonimiGetQueryParamMethodNotAllowedErrorData,
        ElencoOdonimiGetQueryParamNotFoundError,
        ElencoOdonimiGetQueryParamNotFoundErrorData,
        ElencoOdonimiGetQueryParamUnprocessableEntityError,
        ElencoOdonimiGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoodonimipostop import (
        ElencoOdonimiPostBadRequestError,
        ElencoOdonimiPostBadRequestErrorData,
        ElencoOdonimiPostInternalServerError,
        ElencoOdonimiPostInternalServerErrorData,
        ElencoOdonimiPostMethodNotAllowedError,
        ElencoOdonimiPostMethodNotAllowedErrorData,
        ElencoOdonimiPostNotFoundError,
        ElencoOdonimiPostNotFoundErrorData,
        ElencoOdonimiPostUnprocessableEntityError,
        ElencoOdonimiPostUnprocessableEntityErrorData,
    )
    from .elencoodonimiproggetpathparamop import (
        ElencoodonimiprogGetPathParamBadRequestError,
        ElencoodonimiprogGetPathParamBadRequestErrorData,
        ElencoodonimiprogGetPathParamInternalServerError,
        ElencoodonimiprogGetPathParamInternalServerErrorData,
        ElencoodonimiprogGetPathParamMethodNotAllowedError,
        ElencoodonimiprogGetPathParamMethodNotAllowedErrorData,
        ElencoodonimiprogGetPathParamNotFoundError,
        ElencoodonimiprogGetPathParamNotFoundErrorData,
        ElencoodonimiprogGetPathParamUnprocessableEntityError,
        ElencoodonimiprogGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoodonimiproggetqueryparamop import (
        ElencoodonimiprogGetQueryParamBadRequestError,
        ElencoodonimiprogGetQueryParamBadRequestErrorData,
        ElencoodonimiprogGetQueryParamInternalServerError,
        ElencoodonimiprogGetQueryParamInternalServerErrorData,
        ElencoodonimiprogGetQueryParamMethodNotAllowedError,
        ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData,
        ElencoodonimiprogGetQueryParamNotFoundError,
        ElencoodonimiprogGetQueryParamNotFoundErrorData,
        ElencoodonimiprogGetQueryParamUnprocessableEntityError,
        ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoodonimiprogpostop import (
        ElencoodonimiprogPostBadRequestError,
        ElencoodonimiprogPostBadRequestErrorData,
        ElencoodonimiprogPostInternalServerError,
        ElencoodonimiprogPostInternalServerErrorData,
        ElencoodonimiprogPostMethodNotAllowedError,
        ElencoodonimiprogPostMethodNotAllowedErrorData,
        ElencoodonimiprogPostNotFoundError,
        ElencoodonimiprogPostNotFoundErrorData,
        ElencoodonimiprogPostUnprocessableEntityError,
        ElencoodonimiprogPostUnprocessableEntityErrorData,
    )
    from .esisteaccessogetpathparamop import (
        EsisteAccessoGetPathParamBadRequestError,
        EsisteAccessoGetPathParamBadRequestErrorData,
        EsisteAccessoGetPathParamInternalServerError,
        EsisteAccessoGetPathParamInternalServerErrorData,
        EsisteAccessoGetPathParamMethodNotAllowedError,
        EsisteAccessoGetPathParamMethodNotAllowedErrorData,
        EsisteAccessoGetPathParamUnprocessableEntityError,
        EsisteAccessoGetPathParamUnprocessableEntityErrorData,
    )
    from .esisteaccessogetqueryparamop import (
        EsisteAccessoGetQueryParamBadRequestError,
        EsisteAccessoGetQueryParamBadRequestErrorData,
        EsisteAccessoGetQueryParamInternalServerError,
        EsisteAccessoGetQueryParamInternalServerErrorData,
        EsisteAccessoGetQueryParamMethodNotAllowedError,
        EsisteAccessoGetQueryParamMethodNotAllowedErrorData,
        EsisteAccessoGetQueryParamUnprocessableEntityError,
        EsisteAccessoGetQueryParamUnprocessableEntityErrorData,
    )
    from .esisteaccessopostop import (
        EsisteAccessoPostBadRequestError,
        EsisteAccessoPostBadRequestErrorData,
        EsisteAccessoPostInternalServerError,
        EsisteAccessoPostInternalServerErrorData,
        EsisteAccessoPostMethodNotAllowedError,
        EsisteAccessoPostMethodNotAllowedErrorData,
        EsisteAccessoPostUnprocessableEntityError,
        EsisteAccessoPostUnprocessableEntityErrorData,
    )
    from .esisteodonimogetpathparamop import (
        EsisteOdonimoGetPathParamBadRequestError,
        EsisteOdonimoGetPathParamBadRequestErrorData,
        EsisteOdonimoGetPathParamInternalServerError,
        EsisteOdonimoGetPathParamInternalServerErrorData,
        EsisteOdonimoGetPathParamMethodNotAllowedError,
        EsisteOdonimoGetPathParamMethodNotAllowedErrorData,
        EsisteOdonimoGetPathParamUnprocessableEntityError,
        EsisteOdonimoGetPathParamUnprocessableEntityErrorData,
    )
    from .esisteodonimogetqueryparamop import (
        EsisteOdonimoGetQueryParamBadRequestError,
        EsisteOdonimoGetQueryParamBadRequestErrorData,
        EsisteOdonimoGetQueryParamInternalServerError,
        EsisteOdonimoGetQueryParamInternalServerErrorData,
        EsisteOdonimoGetQueryParamMethodNotAllowedError,
        EsisteOdonimoGetQueryParamMethodNotAllowedErrorData,
        EsisteOdonimoGetQueryParamUnprocessableEntityError,
        EsisteOdonimoGetQueryParamUnprocessableEntityErrorData,
    )
    from .esisteodonimopostop import (
        EsisteOdonimoPostBadRequestError,
        EsisteOdonimoPostBadRequestErrorData,
        EsisteOdonimoPostInternalServerError,
        EsisteOdonimoPostInternalServerErrorData,
        EsisteOdonimoPostMethodNotAllowedError,
        EsisteOdonimoPostMethodNotAllowedErrorData,
        EsisteOdonimoPostUnprocessableEntityError,
        EsisteOdonimoPostUnprocessableEntityErrorData,
    )
    from .no_response_error import NoResponseError
    from .prognazaccgetpathparamop import (
        PrognazaccGetPathParamBadRequestError,
        PrognazaccGetPathParamBadRequestErrorData,
        PrognazaccGetPathParamInternalServerError,
        PrognazaccGetPathParamInternalServerErrorData,
        PrognazaccGetPathParamMethodNotAllowedError,
        PrognazaccGetPathParamMethodNotAllowedErrorData,
        PrognazaccGetPathParamNotFoundError,
        PrognazaccGetPathParamNotFoundErrorData,
        PrognazaccGetPathParamUnprocessableEntityError,
        PrognazaccGetPathParamUnprocessableEntityErrorData,
    )
    from .prognazaccgetqueryparamop import (
        PrognazaccGetQueryParamBadRequestError,
        PrognazaccGetQueryParamBadRequestErrorData,
        PrognazaccGetQueryParamInternalServerError,
        PrognazaccGetQueryParamInternalServerErrorData,
        PrognazaccGetQueryParamMethodNotAllowedError,
        PrognazaccGetQueryParamMethodNotAllowedErrorData,
        PrognazaccGetQueryParamNotFoundError,
        PrognazaccGetQueryParamNotFoundErrorData,
        PrognazaccGetQueryParamUnprocessableEntityError,
        PrognazaccGetQueryParamUnprocessableEntityErrorData,
    )
    from .prognazaccpostop import (
        PrognazaccPostBadRequestError,
        PrognazaccPostBadRequestErrorData,
        PrognazaccPostInternalServerError,
        PrognazaccPostInternalServerErrorData,
        PrognazaccPostMethodNotAllowedError,
        PrognazaccPostMethodNotAllowedErrorData,
        PrognazaccPostNotFoundError,
        PrognazaccPostNotFoundErrorData,
        PrognazaccPostUnprocessableEntityError,
        PrognazaccPostUnprocessableEntityErrorData,
    )
    from .prognazareagetpathparamop import (
        PrognazareaGetPathParamBadRequestError,
        PrognazareaGetPathParamBadRequestErrorData,
        PrognazareaGetPathParamInternalServerError,
        PrognazareaGetPathParamInternalServerErrorData,
        PrognazareaGetPathParamMethodNotAllowedError,
        PrognazareaGetPathParamMethodNotAllowedErrorData,
        PrognazareaGetPathParamNotFoundError,
        PrognazareaGetPathParamNotFoundErrorData,
        PrognazareaGetPathParamUnprocessableEntityError,
        PrognazareaGetPathParamUnprocessableEntityErrorData,
    )
    from .prognazareagetqueryparamop import (
        PrognazareaGetQueryParamBadRequestError,
        PrognazareaGetQueryParamBadRequestErrorData,
        PrognazareaGetQueryParamInternalServerError,
        PrognazareaGetQueryParamInternalServerErrorData,
        PrognazareaGetQueryParamMethodNotAllowedError,
        PrognazareaGetQueryParamMethodNotAllowedErrorData,
        PrognazareaGetQueryParamNotFoundError,
        PrognazareaGetQueryParamNotFoundErrorData,
        PrognazareaGetQueryParamUnprocessableEntityError,
        PrognazareaGetQueryParamUnprocessableEntityErrorData,
    )
    from .prognazareapostop import (
        PrognazareaPostBadRequestError,
        PrognazareaPostBadRequestErrorData,
        PrognazareaPostInternalServerError,
        PrognazareaPostInternalServerErrorData,
        PrognazareaPostMethodNotAllowedError,
        PrognazareaPostMethodNotAllowedErrorData,
        PrognazareaPostNotFoundError,
        PrognazareaPostNotFoundErrorData,
        PrognazareaPostUnprocessableEntityError,
        PrognazareaPostUnprocessableEntityErrorData,
    )
    from .responsevalidationerror import ResponseValidationError
    from .show_statusop import ServiceUnavailableError, ServiceUnavailableErrorData

__all__ = [
    "APIError",
    "AnncsuError",
    "ElencoAccessiGetPathParamBadRequestError",
    "ElencoAccessiGetPathParamBadRequestErrorData",
    "ElencoAccessiGetPathParamInternalServerError",
    "ElencoAccessiGetPathParamInternalServerErrorData",
    "ElencoAccessiGetPathParamMethodNotAllowedError",
    "ElencoAccessiGetPathParamMethodNotAllowedErrorData",
    "ElencoAccessiGetPathParamNotFoundError",
    "ElencoAccessiGetPathParamNotFoundErrorData",
    "ElencoAccessiGetPathParamUnprocessableEntityError",
    "ElencoAccessiGetPathParamUnprocessableEntityErrorData",
    "ElencoAccessiGetQueryParamBadRequestError",
    "ElencoAccessiGetQueryParamBadRequestErrorData",
    "ElencoAccessiGetQueryParamInternalServerError",
    "ElencoAccessiGetQueryParamInternalServerErrorData",
    "ElencoAccessiGetQueryParamMethodNotAllowedError",
    "ElencoAccessiGetQueryParamMethodNotAllowedErrorData",
    "ElencoAccessiGetQueryParamNotFoundError",
    "ElencoAccessiGetQueryParamNotFoundErrorData",
    "ElencoAccessiGetQueryParamUnprocessableEntityError",
    "ElencoAccessiGetQueryParamUnprocessableEntityErrorData",
    "ElencoAccessiPostBadRequestError",
    "ElencoAccessiPostBadRequestErrorData",
    "ElencoAccessiPostInternalServerError",
    "ElencoAccessiPostInternalServerErrorData",
    "ElencoAccessiPostMethodNotAllowedError",
    "ElencoAccessiPostMethodNotAllowedErrorData",
    "ElencoAccessiPostNotFoundError",
    "ElencoAccessiPostNotFoundErrorData",
    "ElencoAccessiPostUnprocessableEntityError",
    "ElencoAccessiPostUnprocessableEntityErrorData",
    "ElencoOdonimiGetPathParamBadRequestError",
    "ElencoOdonimiGetPathParamBadRequestErrorData",
    "ElencoOdonimiGetPathParamInternalServerError",
    "ElencoOdonimiGetPathParamInternalServerErrorData",
    "ElencoOdonimiGetPathParamMethodNotAllowedError",
    "ElencoOdonimiGetPathParamMethodNotAllowedErrorData",
    "ElencoOdonimiGetPathParamNotFoundError",
    "ElencoOdonimiGetPathParamNotFoundErrorData",
    "ElencoOdonimiGetPathParamUnprocessableEntityError",
    "ElencoOdonimiGetPathParamUnprocessableEntityErrorData",
    "ElencoOdonimiGetQueryParamBadRequestError",
    "ElencoOdonimiGetQueryParamBadRequestErrorData",
    "ElencoOdonimiGetQueryParamInternalServerError",
    "ElencoOdonimiGetQueryParamInternalServerErrorData",
    "ElencoOdonimiGetQueryParamMethodNotAllowedError",
    "ElencoOdonimiGetQueryParamMethodNotAllowedErrorData",
    "ElencoOdonimiGetQueryParamNotFoundError",
    "ElencoOdonimiGetQueryParamNotFoundErrorData",
    "ElencoOdonimiGetQueryParamUnprocessableEntityError",
    "ElencoOdonimiGetQueryParamUnprocessableEntityErrorData",
    "ElencoOdonimiPostBadRequestError",
    "ElencoOdonimiPostBadRequestErrorData",
    "ElencoOdonimiPostInternalServerError",
    "ElencoOdonimiPostInternalServerErrorData",
    "ElencoOdonimiPostMethodNotAllowedError",
    "ElencoOdonimiPostMethodNotAllowedErrorData",
    "ElencoOdonimiPostNotFoundError",
    "ElencoOdonimiPostNotFoundErrorData",
    "ElencoOdonimiPostUnprocessableEntityError",
    "ElencoOdonimiPostUnprocessableEntityErrorData",
    "ElencoaccessiprogGetPathParamBadRequestError",
    "ElencoaccessiprogGetPathParamBadRequestErrorData",
    "ElencoaccessiprogGetPathParamInternalServerError",
    "ElencoaccessiprogGetPathParamInternalServerErrorData",
    "ElencoaccessiprogGetPathParamMethodNotAllowedError",
    "ElencoaccessiprogGetPathParamMethodNotAllowedErrorData",
    "ElencoaccessiprogGetPathParamNotFoundError",
    "ElencoaccessiprogGetPathParamNotFoundErrorData",
    "ElencoaccessiprogGetPathParamUnprocessableEntityError",
    "ElencoaccessiprogGetPathParamUnprocessableEntityErrorData",
    "ElencoaccessiprogGetQueryParamBadRequestError",
    "ElencoaccessiprogGetQueryParamBadRequestErrorData",
    "ElencoaccessiprogGetQueryParamInternalServerError",
    "ElencoaccessiprogGetQueryParamInternalServerErrorData",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedError",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData",
    "ElencoaccessiprogGetQueryParamNotFoundError",
    "ElencoaccessiprogGetQueryParamNotFoundErrorData",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityError",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData",
    "ElencoaccessiprogPostBadRequestError",
    "ElencoaccessiprogPostBadRequestErrorData",
    "ElencoaccessiprogPostInternalServerError",
    "ElencoaccessiprogPostInternalServerErrorData",
    "ElencoaccessiprogPostMethodNotAllowedError",
    "ElencoaccessiprogPostMethodNotAllowedErrorData",
    "ElencoaccessiprogPostNotFoundError",
    "ElencoaccessiprogPostNotFoundErrorData",
    "ElencoaccessiprogPostUnprocessableEntityError",
    "ElencoaccessiprogPostUnprocessableEntityErrorData",
    "ElencoodonimiprogGetPathParamBadRequestError",
    "ElencoodonimiprogGetPathParamBadRequestErrorData",
    "ElencoodonimiprogGetPathParamInternalServerError",
    "ElencoodonimiprogGetPathParamInternalServerErrorData",
    "ElencoodonimiprogGetPathParamMethodNotAllowedError",
    "ElencoodonimiprogGetPathParamMethodNotAllowedErrorData",
    "ElencoodonimiprogGetPathParamNotFoundError",
    "ElencoodonimiprogGetPathParamNotFoundErrorData",
    "ElencoodonimiprogGetPathParamUnprocessableEntityError",
    "ElencoodonimiprogGetPathParamUnprocessableEntityErrorData",
    "ElencoodonimiprogGetQueryParamBadRequestError",
    "ElencoodonimiprogGetQueryParamBadRequestErrorData",
    "ElencoodonimiprogGetQueryParamInternalServerError",
    "ElencoodonimiprogGetQueryParamInternalServerErrorData",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedError",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData",
    "ElencoodonimiprogGetQueryParamNotFoundError",
    "ElencoodonimiprogGetQueryParamNotFoundErrorData",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityError",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData",
    "ElencoodonimiprogPostBadRequestError",
    "ElencoodonimiprogPostBadRequestErrorData",
    "ElencoodonimiprogPostInternalServerError",
    "ElencoodonimiprogPostInternalServerErrorData",
    "ElencoodonimiprogPostMethodNotAllowedError",
    "ElencoodonimiprogPostMethodNotAllowedErrorData",
    "ElencoodonimiprogPostNotFoundError",
    "ElencoodonimiprogPostNotFoundErrorData",
    "ElencoodonimiprogPostUnprocessableEntityError",
    "ElencoodonimiprogPostUnprocessableEntityErrorData",
    "EsisteAccessoGetPathParamBadRequestError",
    "EsisteAccessoGetPathParamBadRequestErrorData",
    "EsisteAccessoGetPathParamInternalServerError",
    "EsisteAccessoGetPathParamInternalServerErrorData",
    "EsisteAccessoGetPathParamMethodNotAllowedError",
    "EsisteAccessoGetPathParamMethodNotAllowedErrorData",
    "EsisteAccessoGetPathParamUnprocessableEntityError",
    "EsisteAccessoGetPathParamUnprocessableEntityErrorData",
    "EsisteAccessoGetQueryParamBadRequestError",
    "EsisteAccessoGetQueryParamBadRequestErrorData",
    "EsisteAccessoGetQueryParamInternalServerError",
    "EsisteAccessoGetQueryParamInternalServerErrorData",
    "EsisteAccessoGetQueryParamMethodNotAllowedError",
    "EsisteAccessoGetQueryParamMethodNotAllowedErrorData",
    "EsisteAccessoGetQueryParamUnprocessableEntityError",
    "EsisteAccessoGetQueryParamUnprocessableEntityErrorData",
    "EsisteAccessoPostBadRequestError",
    "EsisteAccessoPostBadRequestErrorData",
    "EsisteAccessoPostInternalServerError",
    "EsisteAccessoPostInternalServerErrorData",
    "EsisteAccessoPostMethodNotAllowedError",
    "EsisteAccessoPostMethodNotAllowedErrorData",
    "EsisteAccessoPostUnprocessableEntityError",
    "EsisteAccessoPostUnprocessableEntityErrorData",
    "EsisteOdonimoGetPathParamBadRequestError",
    "EsisteOdonimoGetPathParamBadRequestErrorData",
    "EsisteOdonimoGetPathParamInternalServerError",
    "EsisteOdonimoGetPathParamInternalServerErrorData",
    "EsisteOdonimoGetPathParamMethodNotAllowedError",
    "EsisteOdonimoGetPathParamMethodNotAllowedErrorData",
    "EsisteOdonimoGetPathParamUnprocessableEntityError",
    "EsisteOdonimoGetPathParamUnprocessableEntityErrorData",
    "EsisteOdonimoGetQueryParamBadRequestError",
    "EsisteOdonimoGetQueryParamBadRequestErrorData",
    "EsisteOdonimoGetQueryParamInternalServerError",
    "EsisteOdonimoGetQueryParamInternalServerErrorData",
    "EsisteOdonimoGetQueryParamMethodNotAllowedError",
    "EsisteOdonimoGetQueryParamMethodNotAllowedErrorData",
    "EsisteOdonimoGetQueryParamUnprocessableEntityError",
    "EsisteOdonimoGetQueryParamUnprocessableEntityErrorData",
    "EsisteOdonimoPostBadRequestError",
    "EsisteOdonimoPostBadRequestErrorData",
    "EsisteOdonimoPostInternalServerError",
    "EsisteOdonimoPostInternalServerErrorData",
    "EsisteOdonimoPostMethodNotAllowedError",
    "EsisteOdonimoPostMethodNotAllowedErrorData",
    "EsisteOdonimoPostUnprocessableEntityError",
    "EsisteOdonimoPostUnprocessableEntityErrorData",
    "NoResponseError",
    "PrognazaccGetPathParamBadRequestError",
    "PrognazaccGetPathParamBadRequestErrorData",
    "PrognazaccGetPathParamInternalServerError",
    "PrognazaccGetPathParamInternalServerErrorData",
    "PrognazaccGetPathParamMethodNotAllowedError",
    "PrognazaccGetPathParamMethodNotAllowedErrorData",
    "PrognazaccGetPathParamNotFoundError",
    "PrognazaccGetPathParamNotFoundErrorData",
    "PrognazaccGetPathParamUnprocessableEntityError",
    "PrognazaccGetPathParamUnprocessableEntityErrorData",
    "PrognazaccGetQueryParamBadRequestError",
    "PrognazaccGetQueryParamBadRequestErrorData",
    "PrognazaccGetQueryParamInternalServerError",
    "PrognazaccGetQueryParamInternalServerErrorData",
    "PrognazaccGetQueryParamMethodNotAllowedError",
    "PrognazaccGetQueryParamMethodNotAllowedErrorData",
    "PrognazaccGetQueryParamNotFoundError",
    "PrognazaccGetQueryParamNotFoundErrorData",
    "PrognazaccGetQueryParamUnprocessableEntityError",
    "PrognazaccGetQueryParamUnprocessableEntityErrorData",
    "PrognazaccPostBadRequestError",
    "PrognazaccPostBadRequestErrorData",
    "PrognazaccPostInternalServerError",
    "PrognazaccPostInternalServerErrorData",
    "PrognazaccPostMethodNotAllowedError",
    "PrognazaccPostMethodNotAllowedErrorData",
    "PrognazaccPostNotFoundError",
    "PrognazaccPostNotFoundErrorData",
    "PrognazaccPostUnprocessableEntityError",
    "PrognazaccPostUnprocessableEntityErrorData",
    "PrognazareaGetPathParamBadRequestError",
    "PrognazareaGetPathParamBadRequestErrorData",
    "PrognazareaGetPathParamInternalServerError",
    "PrognazareaGetPathParamInternalServerErrorData",
    "PrognazareaGetPathParamMethodNotAllowedError",
    "PrognazareaGetPathParamMethodNotAllowedErrorData",
    "PrognazareaGetPathParamNotFoundError",
    "PrognazareaGetPathParamNotFoundErrorData",
    "PrognazareaGetPathParamUnprocessableEntityError",
    "PrognazareaGetPathParamUnprocessableEntityErrorData",
    "PrognazareaGetQueryParamBadRequestError",
    "PrognazareaGetQueryParamBadRequestErrorData",
    "PrognazareaGetQueryParamInternalServerError",
    "PrognazareaGetQueryParamInternalServerErrorData",
    "PrognazareaGetQueryParamMethodNotAllowedError",
    "PrognazareaGetQueryParamMethodNotAllowedErrorData",
    "PrognazareaGetQueryParamNotFoundError",
    "PrognazareaGetQueryParamNotFoundErrorData",
    "PrognazareaGetQueryParamUnprocessableEntityError",
    "PrognazareaGetQueryParamUnprocessableEntityErrorData",
    "PrognazareaPostBadRequestError",
    "PrognazareaPostBadRequestErrorData",
    "PrognazareaPostInternalServerError",
    "PrognazareaPostInternalServerErrorData",
    "PrognazareaPostMethodNotAllowedError",
    "PrognazareaPostMethodNotAllowedErrorData",
    "PrognazareaPostNotFoundError",
    "PrognazareaPostNotFoundErrorData",
    "PrognazareaPostUnprocessableEntityError",
    "PrognazareaPostUnprocessableEntityErrorData",
    "ResponseValidationError",
    "ServiceUnavailableError",
    "ServiceUnavailableErrorData",
]

_dynamic_imports: dict[str, str] = {
    "AnncsuError": ".anncsuerror",
    "APIError": ".apierror",
    "ElencoAccessiGetPathParamBadRequestError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamBadRequestErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamInternalServerError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamInternalServerErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamMethodNotAllowedError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamMethodNotAllowedErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamNotFoundError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamNotFoundErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamUnprocessableEntityError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamUnprocessableEntityErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetQueryParamBadRequestError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamBadRequestErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamInternalServerError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamInternalServerErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamMethodNotAllowedError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamMethodNotAllowedErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamNotFoundError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamNotFoundErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamUnprocessableEntityError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamUnprocessableEntityErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiPostBadRequestError": ".elencoaccessipostop",
    "ElencoAccessiPostBadRequestErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostInternalServerError": ".elencoaccessipostop",
    "ElencoAccessiPostInternalServerErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostMethodNotAllowedError": ".elencoaccessipostop",
    "ElencoAccessiPostMethodNotAllowedErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostNotFoundError": ".elencoaccessipostop",
    "ElencoAccessiPostNotFoundErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostUnprocessableEntityError": ".elencoaccessipostop",
    "ElencoAccessiPostUnprocessableEntityErrorData": ".elencoaccessipostop",
    "ElencoaccessiprogGetPathParamBadRequestError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamBadRequestErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamInternalServerError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamInternalServerErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamMethodNotAllowedError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamMethodNotAllowedErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamNotFoundError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamNotFoundErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamUnprocessableEntityError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamUnprocessableEntityErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetQueryParamBadRequestError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamBadRequestErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamInternalServerError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamInternalServerErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamNotFoundError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamNotFoundErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogPostBadRequestError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostBadRequestErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostInternalServerError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostInternalServerErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostMethodNotAllowedError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostMethodNotAllowedErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostNotFoundError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostNotFoundErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostUnprocessableEntityError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostUnprocessableEntityErrorData": ".elencoaccessiprogpostop",
    "ElencoOdonimiGetPathParamBadRequestError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamBadRequestErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamInternalServerError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamInternalServerErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamMethodNotAllowedError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamMethodNotAllowedErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamNotFoundError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamNotFoundErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamUnprocessableEntityError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamUnprocessableEntityErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetQueryParamBadRequestError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamBadRequestErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamInternalServerError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamInternalServerErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamMethodNotAllowedError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamMethodNotAllowedErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamNotFoundError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamNotFoundErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamUnprocessableEntityError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamUnprocessableEntityErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiPostBadRequestError": ".elencoodonimipostop",
    "ElencoOdonimiPostBadRequestErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostInternalServerError": ".elencoodonimipostop",
    "ElencoOdonimiPostInternalServerErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostMethodNotAllowedError": ".elencoodonimipostop",
    "ElencoOdonimiPostMethodNotAllowedErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostNotFoundError": ".elencoodonimipostop",
    "ElencoOdonimiPostNotFoundErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostUnprocessableEntityError": ".elencoodonimipostop",
    "ElencoOdonimiPostUnprocessableEntityErrorData": ".elencoodonimipostop",
    "ElencoodonimiprogGetPathParamBadRequestError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamBadRequestErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamInternalServerError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamInternalServerErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamMethodNotAllowedError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamMethodNotAllowedErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamNotFoundError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamNotFoundErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamUnprocessableEntityError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamUnprocessableEntityErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetQueryParamBadRequestError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamBadRequestErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamInternalServerError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamInternalServerErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamNotFoundError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamNotFoundErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogPostBadRequestError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostBadRequestErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostInternalServerError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostInternalServerErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostMethodNotAllowedError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostMethodNotAllowedErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostNotFoundError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostNotFoundErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostUnprocessableEntityError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostUnprocessableEntityErrorData": ".elencoodonimiprogpostop",
    "EsisteAccessoGetPathParamBadRequestError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamBadRequestErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamInternalServerError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamInternalServerErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamMethodNotAllowedError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamMethodNotAllowedErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamUnprocessableEntityError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamUnprocessableEntityErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetQueryParamBadRequestError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamBadRequestErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamInternalServerError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamInternalServerErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamMethodNotAllowedError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamMethodNotAllowedErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamUnprocessableEntityError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamUnprocessableEntityErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoPostBadRequestError": ".esisteaccessopostop",
    "EsisteAccessoPostBadRequestErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostInternalServerError": ".esisteaccessopostop",
    "EsisteAccessoPostInternalServerErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostMethodNotAllowedError": ".esisteaccessopostop",
    "EsisteAccessoPostMethodNotAllowedErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostUnprocessableEntityError": ".esisteaccessopostop",
    "EsisteAccessoPostUnprocessableEntityErrorData": ".esisteaccessopostop",
    "EsisteOdonimoGetPathParamBadRequestError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamBadRequestErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamInternalServerError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamInternalServerErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamMethodNotAllowedError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamMethodNotAllowedErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamUnprocessableEntityError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamUnprocessableEntityErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetQueryParamBadRequestError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamBadRequestErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamInternalServerError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamInternalServerErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamMethodNotAllowedError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamMethodNotAllowedErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamUnprocessableEntityError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamUnprocessableEntityErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoPostBadRequestError": ".esisteodonimopostop",
    "EsisteOdonimoPostBadRequestErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostInternalServerError": ".esisteodonimopostop",
    "EsisteOdonimoPostInternalServerErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostMethodNotAllowedError": ".esisteodonimopostop",
    "EsisteOdonimoPostMethodNotAllowedErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostUnprocessableEntityError": ".esisteodonimopostop",
    "EsisteOdonimoPostUnprocessableEntityErrorData": ".esisteodonimopostop",
    "NoResponseError": ".no_response_error",
    "PrognazaccGetPathParamBadRequestError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamBadRequestErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamInternalServerError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamInternalServerErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamMethodNotAllowedError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamMethodNotAllowedErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamNotFoundError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamNotFoundErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamUnprocessableEntityError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamUnprocessableEntityErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetQueryParamBadRequestError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamBadRequestErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamInternalServerError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamInternalServerErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamMethodNotAllowedError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamMethodNotAllowedErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamNotFoundError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamNotFoundErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamUnprocessableEntityError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamUnprocessableEntityErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccPostBadRequestError": ".prognazaccpostop",
    "PrognazaccPostBadRequestErrorData": ".prognazaccpostop",
    "PrognazaccPostInternalServerError": ".prognazaccpostop",
    "PrognazaccPostInternalServerErrorData": ".prognazaccpostop",
    "PrognazaccPostMethodNotAllowedError": ".prognazaccpostop",
    "PrognazaccPostMethodNotAllowedErrorData": ".prognazaccpostop",
    "PrognazaccPostNotFoundError": ".prognazaccpostop",
    "PrognazaccPostNotFoundErrorData": ".prognazaccpostop",
    "PrognazaccPostUnprocessableEntityError": ".prognazaccpostop",
    "PrognazaccPostUnprocessableEntityErrorData": ".prognazaccpostop",
    "PrognazareaGetPathParamBadRequestError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamBadRequestErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamInternalServerError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamInternalServerErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamMethodNotAllowedError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamMethodNotAllowedErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamNotFoundError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamNotFoundErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamUnprocessableEntityError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamUnprocessableEntityErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetQueryParamBadRequestError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamBadRequestErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamInternalServerError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamInternalServerErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamMethodNotAllowedError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamMethodNotAllowedErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamNotFoundError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamNotFoundErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamUnprocessableEntityError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamUnprocessableEntityErrorData": ".prognazareagetqueryparamop",
    "PrognazareaPostBadRequestError": ".prognazareapostop",
    "PrognazareaPostBadRequestErrorData": ".prognazareapostop",
    "PrognazareaPostInternalServerError": ".prognazareapostop",
    "PrognazareaPostInternalServerErrorData": ".prognazareapostop",
    "PrognazareaPostMethodNotAllowedError": ".prognazareapostop",
    "PrognazareaPostMethodNotAllowedErrorData": ".prognazareapostop",
    "PrognazareaPostNotFoundError": ".prognazareapostop",
    "PrognazareaPostNotFoundErrorData": ".prognazareapostop",
    "PrognazareaPostUnprocessableEntityError": ".prognazareapostop",
    "PrognazareaPostUnprocessableEntityErrorData": ".prognazareapostop",
    "ResponseValidationError": ".responsevalidationerror",
    "ServiceUnavailableError": ".show_statusop",
    "ServiceUnavailableErrorData": ".show_statusop",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)
