"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EsisteAccessoPostRequestTypedDict(TypedDict):
    r"""search input data"""

    req: NotRequired[str]
    codcom: NotRequired[str]
    denom: NotRequired[str]
    accesso: NotRequired[str]


class EsisteAccessoPostRequest(BaseModel):
    r"""search input data"""

    req: Optional[str] = None

    codcom: Optional[str] = None

    denom: Optional[str] = None

    accesso: Optional[str] = None


class EsisteAccessoPostResponseTypedDict(TypedDict):
    r"""Successful operation"""

    res: NotRequired[str]
    data: NotRequired[bool]


class EsisteAccessoPostResponse(BaseModel):
    r"""Successful operation"""

    res: Optional[str] = None

    data: Optional[bool] = None
