"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class ElencoaccessiprogGetQueryParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetQueryParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: ElencoaccessiprogGetQueryParamInternalServerErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetQueryParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetQueryParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetQueryParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetQueryParamNotFoundErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetQueryParamNotFoundError(AnncsuError):
    r"""Not found"""

    data: ElencoaccessiprogGetQueryParamNotFoundErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetQueryParamNotFoundErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class ElencoaccessiprogGetQueryParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class ElencoaccessiprogGetQueryParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: ElencoaccessiprogGetQueryParamBadRequestErrorData

    def __init__(
        self,
        data: ElencoaccessiprogGetQueryParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data
