"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from ._version import (
    __gen_version__,
    __openapi_doc_version__,
    __user_agent__,
    __version__,
)
from ._version import (
    __title__ as __title__,
)
from .sdk import Anncsu
from .sdkconfiguration import SDKConfiguration

VERSION: str = __version__
OPENAPI_DOC_VERSION = __openapi_doc_version__
SPEAKEASY_GENERATOR_VERSION = __gen_version__
USER_AGENT = __user_agent__

__all__ = [
    "__title__",
    "__version__",
    "__openapi_doc_version__",
    "__gen_version__",
    "__user_agent__",
    "Anncsu",
    "SDKConfiguration",
    "VERSION",
    "OPENAPI_DOC_VERSION",
    "SPEAKEASY_GENERATOR_VERSION",
    "USER_AGENT",
]
